@@ -7,6 +7,8 @@
 #include "drkonqi.h"
 #include "drkonqi_debug.h"
 
+#include <chrono>
+
 #include <QFileDialog>
 #include <QPointer>
 #include <QTemporaryFile>
@@ -26,8 +28,12 @@
 #include "drkonqibackends.h"
 #include "systeminformation.h"
 
+using namespace std::chrono_literals;
+
 DrKonqi::DrKonqi()
-    : m_signal(0)
+    : m_systemInformation(new SystemInformation())
+    , m_backend(new KCrashBackend())
+    , m_signal(0)
     , m_pid(0)
     , m_kdeinit(false)
     , m_safer(false)
@@ -35,8 +41,6 @@ DrKonqi::DrKonqi()
     , m_keepRunning(false)
     , m_thread(0)
 {
-    m_backend = new KCrashBackend();
-    m_systemInformation = new SystemInformation();
 }
 
 DrKonqi::~DrKonqi()
@@ -58,7 +62,7 @@ class EnableCrashCatchingDelayed : public QObject
 public:
     EnableCrashCatchingDelayed()
     {
-        startTimer(10000); // 10 s
+        startTimer(10s);
     }
 
 protected:
@@ -261,6 +265,11 @@ void DrKonqi::setProgramName(const QString &programName)
     instance()->m_programName = programName;
 }
 
+void DrKonqi::setProductName(const QString &productName)
+{
+    instance()->m_productName = productName;
+}
+
 void DrKonqi::setPid(int pid)
 {
     instance()->m_pid = pid;
@@ -291,6 +300,11 @@ void DrKonqi::setThread(int thread)
     instance()->m_thread = thread;
 }
 
+void DrKonqi::setStartupId(const QString &startupId)
+{
+    instance()->m_startupId = startupId;
+}
+
 int DrKonqi::signal()
 {
     return instance()->m_signal;
@@ -321,6 +335,11 @@ const QString &DrKonqi::programName()
     return instance()->m_programName;
 }
 
+const QString &DrKonqi::productName()
+{
+    return instance()->m_productName;
+}
+
 int DrKonqi::pid()
 {
     return instance()->m_pid;
@@ -383,4 +402,9 @@ const QString &DrKonqi::kdeBugzillaURL()
     return url;
 }
 
+const QString &DrKonqi::startupId()
+{
+    return instance()->m_startupId;
+}
+
 #include "drkonqi.moc"
